@@ -23,7 +23,7 @@
 #include "stringmatcher.h"
 
 class QFileInfo;
-class CvsService_stub;
+class OrgKdeCervisiaCvsserviceCvsserviceInterface;
 
 
 namespace Cervisia
@@ -37,7 +37,7 @@ public:
 
     virtual bool matches(const QFileInfo* fi) const;
     
-    void retrieveServerIgnoreList(CvsService_stub* cvsService,
+    void retrieveServerIgnoreList(OrgKdeCervisiaCvsserviceCvsserviceInterface* cvsService,
                                   const QString& repository);
 
 private:
