@@ -26,6 +26,7 @@
 #include <kaction.h>
 #include <kactionmenu.h>
 #include <kactioncollection.h>
+#include <kcombobox.h>
 #include <kconfig.h>
 #include <kdialog.h>
 #include <kdirwatch.h>
@@ -34,6 +35,7 @@
 #include <kicondialog.h>
 #include <kiconloader.h>
 #include <kio/netaccess.h>
+#include <klineedit.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 // #include <knewstuff2/core/entry.h>
@@ -46,12 +48,10 @@
 
 #include <qbuttongroup.h>
 #include <qcheckbox.h>
-#include <qcombobox.h>
 #include <qcursor.h>
 #include <qdatetime.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qradiobutton.h>
 #include <qregexp.h>
@@ -73,14 +73,16 @@
 #include <ktexteditor/templateinterface.h>
 #include <krecentfilesaction.h>
 
-#include <kgenericfactory.h>
+#include <kpluginfactory.h>
+#include <kpluginloader.h>
+#include <kaboutdata.h>
 #include <kmenu.h>
 //END Includes
 
 //BEGIN plugin + factory stuff
 
-K_EXPORT_COMPONENT_FACTORY( katefiletemplates,
-                            KGenericFactory<KateFileTemplates>( "katefiletemplates" ) )
+K_PLUGIN_FACTORY(KateFileTemplatesFactory, registerPlugin<KateFileTemplates>();)
+K_EXPORT_PLUGIN(KateFileTemplatesFactory(KAboutData("katefiletemplates","katefiletemplates",ki18n("File Templates"), "0.1", ki18n("Create files from templates"), KAboutData::License_LGPL_V2)) )
 
 //END
 
@@ -88,6 +90,8 @@ K_EXPORT_COMPONENT_FACTORY( katefiletemplates,
 PluginViewKateFileTemplates::PluginViewKateFileTemplates(KateFileTemplates *plugin, Kate::MainWindow *mainwindow):
   Kate::PluginView(mainwindow),KXMLGUIClient(),m_plugin(plugin)
 {
+  setComponentData (KateFileTemplatesFactory::componentData());
+  setXMLFile("plugins/katefiletemplates/ui.rc");
   QAction *a = actionCollection()->addAction("settings_manage_templates");
   a->setText(i18n("&Manage Templates..."));
   connect( a, SIGNAL( triggered(bool) ), plugin, SLOT( slotEditTemplate() ) );
@@ -96,8 +100,6 @@ PluginViewKateFileTemplates::PluginViewKateFileTemplates(KateFileTemplates *plug
   actionCollection()->addAction("file_new_fromtemplate",a);
   refreshMenu();
 
-  setComponentData (KComponentData("kate"));
-  setXMLFile("plugins/katefiletemplates/ui.rc");
   mainwindow->guiFactory()->addClient (this);
 
 }
@@ -132,7 +134,7 @@ Q_DECLARE_METATYPE(TemplateInfo*)
 //END TemplateInfo
 
 //BEGIN KateFileTemplates
-KateFileTemplates::KateFileTemplates( QObject* parent, const QStringList &dummy)
+KateFileTemplates::KateFileTemplates( QObject* parent, const QList<QVariant> &dummy)
     : Kate::Plugin ( (Kate::Application*)parent)
 {
     Q_UNUSED(dummy)
@@ -146,8 +148,8 @@ KateFileTemplates::KateFileTemplates( QObject* parent, const QStringList &dummy)
   // template menu
   m_dw = new KDirWatch( this);
   m_dw->setObjectName( "template_dirwatch" );
-  QStringList dirs = KGlobal::dirs()->findDirs("data", "kate/plugins/katefiletemplates/templates");
-  for ( QStringList::Iterator it = dirs.begin(); it != dirs.end(); ++it )
+  const QStringList dirs = KGlobal::dirs()->findDirs("data", "kate/plugins/katefiletemplates/templates");
+  for ( QStringList::const_iterator it = dirs.begin(); it != dirs.end(); ++it )
   {
     m_dw->addDir( *it, KDirWatch::WatchFiles );
   }
@@ -173,7 +175,7 @@ void KateFileTemplates::updateTemplateDirs(const QString &d)
 {
   kDebug()<<"updateTemplateDirs called with arg "<<d;
 
-  QStringList templates = KGlobal::dirs()->findAllResources(
+  const QStringList templates = KGlobal::dirs()->findAllResources(
       "data","kate/plugins/katefiletemplates/templates/*.katetemplate",
       KStandardDirs::NoDuplicates);
 
@@ -186,7 +188,7 @@ void KateFileTemplates::updateTemplateDirs(const QString &d)
   QStringList hidden;
   cg.readXdgListEntry( "Hidden", hidden ); // XXX this is bogus
 
-  for ( QStringList::Iterator it=templates.begin(); it != templates.end(); ++it )
+  for ( QStringList::const_iterator it=templates.begin(); it != templates.end(); ++it )
   {
     QFile _f( *it );
     if ( _f.open( QIODevice::ReadOnly ) )
@@ -531,7 +533,7 @@ KateTemplateInfoWidget::KateTemplateInfoWidget( QWidget *parent, TemplateInfo *i
   QLabel *l = new QLabel( i18n("&Template:"), this );
   KHBox *hb = new KHBox( this );
   hb->setSpacing( KDialog::spacingHint() );
-  leTemplate = new QLineEdit( hb );
+  leTemplate = new KLineEdit( hb );
   l->setBuddy( leTemplate );
   leTemplate->setToolTip( i18n("<p>This string is used as the template's name "
       "and is displayed, for example, in the Template menu. It should describe the "
@@ -541,7 +543,7 @@ KateTemplateInfoWidget::KateTemplateInfoWidget( QWidget *parent, TemplateInfo *i
       "Press to select or change the icon for this template") );
 
   l = new QLabel( i18n("&Group:"), this );
-  cmbGroup = new QComboBox( true, this );
+  cmbGroup = new KComboBox( true, this );
   cmbGroup->insertStringList( kft->groups() );
   l->setBuddy( cmbGroup );
   cmbGroup->setToolTip(i18n("<p>The group is used for choosing a "
@@ -549,7 +551,7 @@ KateTemplateInfoWidget::KateTemplateInfoWidget( QWidget *parent, TemplateInfo *i
       "<p>You can type any string to add a new group to your menu.</p>") );
 
   l = new QLabel( i18n("Document &name:"), this );
-  leDocumentName = new QLineEdit( this );
+  leDocumentName = new KLineEdit( this );
   l->setBuddy( leDocumentName );
   leDocumentName->setToolTip( i18n("<p>This string will be used to set a name "
       "for the new document, to display in the title bar and file list.</p>"
@@ -566,14 +568,14 @@ KateTemplateInfoWidget::KateTemplateInfoWidget( QWidget *parent, TemplateInfo *i
     "template. If 'None' is chosen, the property will not be set.</p>") );
 
   l = new QLabel( i18n("&Description:"), this );
-  leDescription = new QLineEdit( this );
+  leDescription = new KLineEdit( this );
   l->setBuddy( leDescription );
   leDescription->setToolTip(i18n("<p>This string is used, for example, as "
       "context help for this template (such as the 'whatsthis' help for the "
       "menu item.)</p>") );
 
   l = new QLabel( i18n("&Author:"), this );
-  leAuthor = new QLineEdit( this );
+  leAuthor = new KLineEdit( this );
   l->setBuddy( leAuthor );
   leAuthor->setToolTip(i18n("<p>You can set this if you want to share your "
       "template with other users.</p>"
@@ -744,7 +746,7 @@ KateTemplateWizard::KateTemplateWizard( QWidget *parent, KateFileTemplates *kft
   rb->setChecked( true );
 
   glo->addMultiCell( new QSpacerItem( marg, 1, QSizePolicy::Fixed ), 3, 4, 1, 1 );
-  leTemplateFileName = new QLineEdit( page );
+  leTemplateFileName = new KLineEdit( page );
   QLabel *l = new QLabel( leTemplateFileName, i18n("Template &file name:"), page );
 
   glo->addWidget( l, 3, 2 );
@@ -906,7 +908,7 @@ void KateTemplateWizard::accept()
 
     templateUrl = dir + suggestion;
 
-    if ( QFile::exists( templateUrl.path() ) )
+    if ( QFile::exists( templateUrl.toLocalFile() ) )
     {
       if ( KMessageBox::warningContinueCancel( this, i18n(
           "<p>The file <br /><strong>'%1'</strong><br /> already exists; if you "
@@ -1017,7 +1019,7 @@ void KateTemplateWizard::accept()
   {
     if ( templateUrl.isLocalFile() )
     {
-      QFile file( templateUrl.path() );
+      QFile file( templateUrl.toLocalFile() );
          if ( file.open(QIODevice::WriteOnly) )
       {
         kDebug()<<"file opened with succes";
@@ -1160,11 +1162,11 @@ void KateTemplateManager::slotRemoveTemplate()
     KSharedConfig::Ptr config = KGlobal::config();
     TemplateInfo *info =  item->data(0, Qt::UserRole).value<TemplateInfo*>();
     QString fname = info->filename.section( '/', -1 );
-    QStringList templates = KGlobal::dirs()->findAllResources(
+    const QStringList templates = KGlobal::dirs()->findAllResources(
         "data", fname.prepend( "kate/plugins/katefiletemplates/templates/" ),KStandardDirs::NoDuplicates);
     int failed = 0;
     int removed = 0;
-    for ( QStringList::Iterator it=templates.begin(); it!=templates.end(); ++it )
+    for ( QStringList::const_iterator it=templates.begin(); it!=templates.end(); ++it )
     {
       if ( ! QFile::remove(*it) )
         failed++;
