@@ -308,7 +308,15 @@ bool KateBuildView::slotMakeClean(void)
 /******************************************************************/
 bool KateBuildView::slotQuickCompile()
 {
-    return startProcess(buildUi.quickComp->text());
+    KTextEditor::View *kv = mainWindow()->activeView();
+    if (!kv) {
+        KMessageBox::sorry(0, i18n("There is no file or directory specified for building."));
+        return false;
+    }
+    if (kv->document()->isModified()) kv->document()->save();
+    KUrl url(kv->document()->url());
+    
+    return startProcess(buildUi.quickComp->text() + " "  + url.toLocalFile());
 }
 
 /******************************************************************/
@@ -337,7 +345,7 @@ bool KateBuildView::startProcess(const QString &command)
     // where should we run make?
 
     if (buildUi.buildDir->text().isEmpty()) {
-        if (url.path().isEmpty()) {
+        if (url.toLocalFile().isEmpty()) {
             KMessageBox::sorry(0, i18n("There is no file or directory specified for building."));
             return false;
         }
@@ -348,7 +356,8 @@ bool KateBuildView::startProcess(const QString &command)
                                        url.path()));
             return false;
         }
-        m_make_dir = url;
+        // url is a file -> remove the file with upUrl().
+        m_make_dir = url.upUrl();
     }
     else {
         m_make_dir = KUrl(buildUi.buildDir->text());
@@ -388,12 +397,12 @@ bool KateBuildView::slotStop()
 }
 
 /******************************************************************/
-void KateBuildView::slotProcExited(int /*exitCode*/, QProcess::ExitStatus)
+void KateBuildView::slotProcExited(int exitCode, QProcess::ExitStatus)
 {
     QApplication::restoreOverrideCursor();
 
     // did we get any errors?
-    if (m_found_error) {
+    if (m_found_error || (exitCode != 0)) {
         buildUi.ktabwidget->setCurrentIndex(0);
         buildUi.errTreeWidget->resizeColumnToContents(0);
         buildUi.errTreeWidget->resizeColumnToContents(1);
