@@ -1,22 +1,43 @@
-#include <kdebug.h>
-#include <kconfig.h>
-#include <klocale.h>
+/* This file is part of kdesdk / KBugBuster.
 
+   Copyright 2008  KBugBuster Authors <kde-ev-board@kde.org>
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License as
+   published by the Free Software Foundation; either version 2 of
+   the License or (at your option) version 3 or any later version
+   accepted by the membership of KDE e.V. (or its successor approved
+   by the membership of KDE e.V.), which shall act as a proxy 
+   defined in Section 14 of version 3 of the license.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 #include "bugcommand.h"
 
-QString BugCommand::name()
+#include <kdebug.h>
+#include <kconfig.h>
+#include <kconfiggroup.h>
+#include <klocale.h>
+
+QString BugCommand::name() const
 {
     return i18n("Unknown");
 }
 
-QString BugCommand::details()
+QString BugCommand::details() const
 {
-    return QString::null;
+    return QString();
 }
 
-BugCommand *BugCommand::load( KConfig *config, const QString &type )
+BugCommand *BugCommand::load( KConfigGroup *grp, const QString &type )
 {
-    QString bugNumber = config->group();
+    QString bugNumber = grp->name();
     // ### this sucks. we better let Bug implement proper persistance,
     // because this way of instantiating a bug object doesn't bring back
     // properties like title, package, etc. (Simon)
@@ -24,27 +45,27 @@ BugCommand *BugCommand::load( KConfig *config, const QString &type )
     Package pkg = Package(); // hack
 
     if ( type == "Close" ) {
-        return new BugCommandClose( bug, config->readEntry( type ), pkg );
+        return new BugCommandClose( bug, grp->readEntry( type,QString() ), pkg );
     } else if ( type == "Reopen" ) {
         return new BugCommandReopen( bug, pkg );
     } else if ( type == "Merge" ) {
-        return new BugCommandMerge( config->readListEntry( type ), pkg );
+        return new BugCommandMerge( grp->readEntry( type , QStringList() ), pkg );
     } else if ( type == "Unmerge" ) {
         return new BugCommandUnmerge( bug, pkg );
     } else if ( type == "Reassign" ) {
-        return new BugCommandReassign( bug, config->readEntry( type ), pkg );
+        return new BugCommandReassign( bug, grp->readEntry( type,QString() ), pkg );
     } else if ( type == "Retitle" ) {
-        return new BugCommandRetitle( bug, config->readEntry( type ), pkg );
+        return new BugCommandRetitle( bug, grp->readEntry( type, QString() ), pkg );
     } else if ( type == "Severity" ) {
-        return new BugCommandSeverity( bug, config->readEntry( type ), pkg );
+        return new BugCommandSeverity( bug, grp->readEntry( type,QString() ), pkg );
     } else if ( type == "Reply" ) {
-        return new BugCommandReply( bug, config->readEntry( type ), config->readNumEntry("Recipient",Normal) );
+        return new BugCommandReply( bug, grp->readEntry( type,QString() ), grp->readEntry("Recipient",int(Normal)) );
     } else if ( type == "ReplyPrivate" ) {
-        QStringList args = config->readListEntry( type );
+        QStringList args = grp->readEntry( type , QStringList() );
         if ( args.count() != 2 ) return 0;
-        return new BugCommandReplyPrivate( bug, *(args.at(0)), *(args.at(1)) );
+        return new BugCommandReplyPrivate( bug, (args.at(0)), (args.at(1)) );
     } else {
-      kdDebug() << "Warning! Unknown bug command '" << type << "'" << endl;
+      kDebug() << "Warning! Unknown bug command '" << type << "'";
       return 0;
     }
 }
@@ -56,16 +77,16 @@ QString BugCommandClose::controlString() const
     if (m_message.isEmpty()) {
         return "close " + m_bug.number();
     } else {
-        return QString::null;
+        return QString();
     }
 }
 
 QString BugCommandClose::mailAddress() const
 {
-    kdDebug() << "BugCommandClose::mailAddress(): number: " << m_bug.number() << endl;
+    kDebug() << "BugCommandClose::mailAddress(): number: " << m_bug.number();
 
     if (m_message.isEmpty()) {
-        return QString::null;
+        return QString();
     } else {
         return m_bug.number() + "-done@bugs.kde.org";
     }
@@ -74,25 +95,25 @@ QString BugCommandClose::mailAddress() const
 QString BugCommandClose::mailText() const
 {
     if (m_message.isEmpty()) {
-        return QString::null;
+        return QString();
     } else {
         return m_message;
     }
 }
 
-QString BugCommandClose::name()
+QString BugCommandClose::name() const
 {
     return i18n("Close");
 }
 
-QString BugCommandClose::details()
+QString BugCommandClose::details() const
 {
     return m_message;
 }
 
-void BugCommandClose::save( KConfig *config )
+void BugCommandClose::save( KConfigGroup *grp )
 {
-    config->writeEntry( "Close",m_message );
+    grp->writeEntry( "Close",m_message );
 }
 
 ///////////////////// Close Silently /////////////////////
@@ -102,14 +123,14 @@ QString BugCommandCloseSilently::controlString() const
     return "done " + m_bug.number();
 }
 
-QString BugCommandCloseSilently::name()
+QString BugCommandCloseSilently::name() const
 {
     return i18n("Close Silently");
 }
 
-void BugCommandCloseSilently::save( KConfig *config )
+void BugCommandCloseSilently::save( KConfigGroup *grp )
 {
-    config->writeEntry( "CloseSilently", true );
+    grp->writeEntry( "CloseSilently", true );
 }
 
 ///////////////////// Reopen /////////////////////
@@ -119,36 +140,36 @@ QString BugCommandReopen::controlString() const
     return "reopen " + m_bug.number();
 }
 
-QString BugCommandReopen::name()
+QString BugCommandReopen::name() const
 {
     return i18n("Reopen");
 }
 
-void BugCommandReopen::save( KConfig *config )
+void BugCommandReopen::save( KConfigGroup *grp )
 {
-    config->writeEntry( "Reopen", true );
+    grp->writeEntry( "Reopen", true );
 }
 
 ///////////////////// Retitle /////////////////////
 
 QString BugCommandRetitle::controlString() const
 {
-    return "retitle " + m_bug.number() + " " + m_title;
+    return "retitle " + m_bug.number() + ' ' + m_title;
 }
 
-QString BugCommandRetitle::name()
+QString BugCommandRetitle::name() const
 {
     return i18n("Retitle");
 }
 
-QString BugCommandRetitle::details()
+QString BugCommandRetitle::details() const
 {
     return m_title;
 }
 
-void BugCommandRetitle::save( KConfig *config )
+void BugCommandRetitle::save( KConfigGroup *grp )
 {
-    config->writeEntry( "Retitle", m_title );
+    grp->writeEntry( "Retitle", m_title );
 }
 
 ///////////////////// Merge /////////////////////
@@ -158,19 +179,19 @@ QString BugCommandMerge::controlString() const
     return "merge " + m_bugNumbers.join(" ");
 }
 
-QString BugCommandMerge::name()
+QString BugCommandMerge::name() const
 {
     return i18n("Merge");
 }
 
-QString BugCommandMerge::details()
+QString BugCommandMerge::details() const
 {
     return m_bugNumbers.join(", ");
 }
 
-void BugCommandMerge::save( KConfig *config )
+void BugCommandMerge::save( KConfigGroup *grp )
 {
-    config->writeEntry( "Merge", m_bugNumbers );
+    grp->writeEntry( "Merge", m_bugNumbers );
 }
 
 ///////////////////// Unmerge /////////////////////
@@ -180,14 +201,14 @@ QString BugCommandUnmerge::controlString() const
     return "unmerge " + m_bug.number();
 }
 
-QString BugCommandUnmerge::name()
+QString BugCommandUnmerge::name() const
 {
     return i18n("Unmerge");
 }
 
-void BugCommandUnmerge::save( KConfig *config )
+void BugCommandUnmerge::save( KConfigGroup *grp )
 {
-    config->writeEntry( "Unmerge", true );
+    grp->writeEntry( "Unmerge", true );
 }
 
 ///////////////////// Reply /////////////////////
@@ -204,7 +225,7 @@ QString BugCommandReply::mailAddress() const
       case Quiet:
         return m_bug.number() + "-quiet@bugs.kde.org";
     }
-    return QString::null;
+    return QString();
 #endif
 }
 
@@ -213,7 +234,7 @@ QString BugCommandReply::mailText() const
     return m_message;
 }
 
-QString BugCommandReply::name()
+QString BugCommandReply::name() const
 {
     return i18n("Reply");
 #if 0
@@ -225,20 +246,20 @@ QString BugCommandReply::name()
       case Quiet:
         return i18n("Reply (Quiet)");
     }
-    return QString::null;
+    return QString();
 #endif
 }
 
-QString BugCommandReply::details()
+QString BugCommandReply::details() const
 {
     return m_message;
 }
 
-void BugCommandReply::save( KConfig *config )
+void BugCommandReply::save( KConfigGroup *grp )
 {
-    config->writeEntry( "Reply", m_message );
+    grp->writeEntry( "Reply", m_message );
 #if 0
-    config->writeEntry( "Recipient", m_recipient );
+    grp->writeEntry( "Recipient", m_recipient );
 #endif
 }
 
@@ -254,64 +275,64 @@ QString BugCommandReplyPrivate::mailText() const
     return m_message;
 }
 
-QString BugCommandReplyPrivate::name()
+QString BugCommandReplyPrivate::name() const
 {
     return i18n("Private Reply");
 }
 
-QString BugCommandReplyPrivate::details()
+QString BugCommandReplyPrivate::details() const
 {
     return m_message;
 }
 
-void BugCommandReplyPrivate::save( KConfig *config )
+void BugCommandReplyPrivate::save( KConfigGroup *grp )
 {
     QStringList args;
     args << m_address;
     args << m_message;
-    config->writeEntry( "ReplyPrivate", args );
+    grp->writeEntry( "ReplyPrivate", args );
 }
 
 ///////////////////// Severity /////////////////////
 
 QString BugCommandSeverity::controlString() const
 {
-    return "severity " + m_bug.number() + " " + m_severity.lower();
+    return "severity " + m_bug.number() + ' ' + m_severity.toLower();
 }
 
-QString BugCommandSeverity::name()
+QString BugCommandSeverity::name() const
 {
     return i18n("Severity");
 }
 
-QString BugCommandSeverity::details()
+QString BugCommandSeverity::details() const
 {
     return m_severity;
 }
 
-void BugCommandSeverity::save( KConfig *config )
+void BugCommandSeverity::save( KConfigGroup *grp )
 {
-    config->writeEntry( "Severity", m_severity );
+    grp->writeEntry( "Severity", m_severity );
 }
 
 ///////////////////// Reassign /////////////////////
 
 QString BugCommandReassign::controlString() const
 {
-    return "reassign " + m_bug.number() + " " + m_package;
+    return "reassign " + m_bug.number() + ' ' + m_package;
 }
 
-QString BugCommandReassign::name()
+QString BugCommandReassign::name() const
 {
     return i18n("Reassign");
 }
 
-QString BugCommandReassign::details()
+QString BugCommandReassign::details() const
 {
     return m_package;
 }
 
-void BugCommandReassign::save( KConfig *config )
+void BugCommandReassign::save( KConfigGroup *grp )
 {
-    config->writeEntry( "Reassign", m_package );
+    grp->writeEntry( "Reassign", m_package );
 }
