@@ -13,36 +13,34 @@
     *                                                                       *
     *************************************************************************
 */
+#include "cwbuglistcontainer.h"
 
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qwidgetstack.h>
+#include <QPushButton>
+#include <QLabel>
+#include <QLayout>
+#include <QStackedWidget>
+#include <QVBoxLayout>
+#include <QBoxLayout>
 
-#include <kapplication.h>
 #include <kiconloader.h>
-#include <klistview.h>
+#include <k3listview.h>
 #include <klocale.h>
 #include <kdialog.h>
-#if KDE_IS_VERSION( 3, 2, 90 )
-#include <klistviewsearchline.h>
-#endif
+#include <k3listviewsearchline.h>
 #include <kdebug.h>
 
 #include "bugsystem.h"
 
 #include "cwloadingwidget.h"
-#include "buglvi.h"
 #include "kbbprefs.h"
 #include "kfind.h"
 
-#include "cwbuglistcontainer.h"
 #include <kfinddialog.h>
 
 using namespace KBugBusterMainWindow;
 
-CWBugListContainer::CWBugListContainer( QWidget *parent , const char * name )
-  : QWidget( parent, name ), m_find(0), m_findItem(0)
+CWBugListContainer::CWBugListContainer( QWidget *parent )
+  : QWidget( parent ), m_find(0), m_findItem(0)
 {
     QBoxLayout *topLayout = new QVBoxLayout( this );
     topLayout->setSpacing( KDialog::spacingHint() );
@@ -56,12 +54,12 @@ CWBugListContainer::CWBugListContainer( QWidget *parent , const char * name )
     f.setBold( true );
     m_listLabel->setFont( f );
 
-    m_listStack = new QWidgetStack( this );
+    m_listStack = new QStackedWidget( this );
 
     // Create Outstanding Bugs listview
-    m_listBugs = new KListView( m_listStack );
+    m_listBugs = new K3ListView( m_listStack );
 
-    topLayout->addWidget( new KListViewSearchLineWidget( m_listBugs, this ) );
+    topLayout->addWidget( new K3ListViewSearchLineWidget( m_listBugs, this ) );
     topLayout->addWidget( m_listStack );
     topLayout->setStretchFactor( m_listStack, 1 );
 
@@ -72,27 +70,27 @@ CWBugListContainer::CWBugListContainer( QWidget *parent , const char * name )
     m_listBugs->addColumn( i18n( "Severity" ) );
     m_listBugs->addColumn( i18n( "Sender" ), 150 ); // idem. hardcoded widths suck a bit, but...
     m_listBugs->setAllColumnsShowFocus( true );
-    m_listBugs->setColumnAlignment( 0, AlignRight );
+    m_listBugs->setColumnAlignment( 0, Qt::AlignRight );
     m_listBugs->setSorting( 0, false );
     m_listBugs->setShowSortIndicator( true );
-    m_listBugs->setSelectionMode( QListView::Extended ); // needed for merging bugs
+    m_listBugs->setSelectionMode( Q3ListView::Extended ); // needed for merging bugs
 
     m_listBugs->restoreLayout( KBBPrefs::instance()->config(), "BugListLayout" );
 
-    connect( m_listBugs, SIGNAL( executed( QListViewItem * ) ),
-             SLOT( execute( QListViewItem * ) ) );
-    connect( m_listBugs, SIGNAL( returnPressed( QListViewItem * ) ),
-             SLOT( execute( QListViewItem * ) ) );
-    connect( m_listBugs, SIGNAL( currentChanged( QListViewItem * ) ),
-             SLOT( changeCurrent( QListViewItem * ) ) );
+    connect( m_listBugs, SIGNAL( executed( Q3ListViewItem * ) ),
+             SLOT( execute( Q3ListViewItem * ) ) );
+    connect( m_listBugs, SIGNAL( returnPressed( Q3ListViewItem * ) ),
+             SLOT( execute( Q3ListViewItem * ) ) );
+    connect( m_listBugs, SIGNAL( currentChanged( Q3ListViewItem * ) ),
+             SLOT( changeCurrent( Q3ListViewItem * ) ) );
 
     // Fill WidgetStack in Outstanding Bugs pane
     m_listLoading = new CWLoadingWidget( CWLoadingWidget::TopFrame,
                                          m_listStack );
     connect( m_listLoading, SIGNAL( clicked() ), SIGNAL( searchPackage() ) );
 
-    m_listStack->addWidget( m_listBugs, 0 );
-    m_listStack->addWidget( m_listLoading,  1 );
+    m_listStack->insertWidget( 0,m_listBugs );
+    m_listStack->insertWidget( 1,m_listLoading );
 
     setNoList();
 
@@ -143,8 +141,8 @@ void CWBugListContainer::setBugList( const QString &label, const Bug::List &bugs
         }
     }
 
-    m_listLabel->setText( i18n( "%1 (%2 bugs, %3 wishes)" ).arg( label ).arg( noBugs ).arg( noWishes ) );
-    m_listStack->raiseWidget( 0 );
+    m_listLabel->setText( i18n( "%1 (%2 bugs, %3 wishes)", label, noBugs, noWishes ) );
+    m_listStack->setCurrentIndex( 0 );
 }
 
 void CWBugListContainer::setBugList( const Package &package, const QString &component, const Bug::List &bugs )
@@ -153,24 +151,24 @@ void CWBugListContainer::setBugList( const Package &package, const QString &comp
     if ( component.isEmpty() )
     {
         if ( package.components().count() > 1 )
-            listLabel = i18n( "Product '%1', all components" ).arg( package.name() );
+            listLabel = i18n( "Product '%1', all components", package.name() );
         else
-            listLabel = i18n( "Product '%1'" ).arg( package.name() );
+            listLabel = i18n( "Product '%1'", package.name() );
     }
     else
     {
-        listLabel = i18n( "Product '%1', component '%2'" ).arg( package.name(), component );
+        listLabel = i18n( "Product '%1', component '%2'", package.name(), component );
     }
 
     setBugList( listLabel, bugs );
 }
 
-void CWBugListContainer::execute( QListViewItem *lvi )
+void CWBugListContainer::execute( Q3ListViewItem *lvi )
 {
     BugLVI *item = dynamic_cast<BugLVI *>( lvi );
     if( !item )
     {
-        kdWarning() << "CWBugListContainer::execute() Selected bug "
+        kWarning() << "CWBugListContainer::execute() Selected bug "
                     << lvi->text( 0 )
                     << " is not a BugLVI! Ignoring event." << endl;
         return;
@@ -179,7 +177,7 @@ void CWBugListContainer::execute( QListViewItem *lvi )
     emit executed( item->bug() );
 }
 
-void CWBugListContainer::changeCurrent( QListViewItem *lvi )
+void CWBugListContainer::changeCurrent( Q3ListViewItem *lvi )
 {
     if( !lvi ) {
         emit currentChanged( Bug() );
@@ -189,7 +187,7 @@ void CWBugListContainer::changeCurrent( QListViewItem *lvi )
     BugLVI *item = dynamic_cast<BugLVI *>( lvi );
     if( !item )
     {
-        kdWarning() << "CWBugListContainer::changeCurrent() Selected bug "
+        kWarning() << "CWBugListContainer::changeCurrent() Selected bug "
                     << lvi->text( 0 )
                     << " is not a BugLVI! Ignoring event." << endl;
         return;
@@ -202,32 +200,32 @@ void CWBugListContainer::setNoList()
 {
     m_listLabel->setText( i18n("Outstanding Bugs") );
     m_listLoading->setText( i18n( "Click here to select a product" ) );
-    m_listStack->raiseWidget( 1 );
+    m_listStack->setCurrentIndex( 1 );
 }
 
 void CWBugListContainer::setLoading( const Package &package, const QString &component )
 {
     if ( component.isEmpty() )
-        setLoading( i18n( "Retrieving List of Outstanding Bugs for Product '%1'..." ).arg( package.name() ) );
+        setLoading( i18n( "Retrieving List of Outstanding Bugs for Product '%1'...", package.name() ) );
     else
-        setLoading( i18n( "Retrieving List of Outstanding Bugs for Product '%1' (Component %2)..." ).arg( package.name(), component ) );
+        setLoading( i18n( "Retrieving List of Outstanding Bugs for Product '%1' (Component %2)...", package.name(), component ) );
 }
 
 void CWBugListContainer::setLoading( const QString &label )
 {
     m_listLoading->setText( label );
-    m_listStack->raiseWidget( 1 );
+    m_listStack->setCurrentIndex( 1 );
 }
 
 void CWBugListContainer::setCacheMiss( const Package &package )
 {
-    setCacheMiss( i18n( "Package '%1'" ).arg( package.name() ) );
+    setCacheMiss( i18n( "Package '%1'", package.name() ) );
 }
 
 void CWBugListContainer::setCacheMiss( const QString &label )
 {
-    m_listLoading->setText( i18n( "%1 is not available offline." ).arg( label ) );
-    m_listStack->raiseWidget( 1 );
+    m_listLoading->setText( i18n( "%1 is not available offline.", label ) );
+    m_listStack->setCurrentIndex( 1 );
 }
 
 void CWBugListContainer::markBugCommand( BugCommand *cmd )
@@ -266,7 +264,7 @@ void CWBugListContainer::searchBugByTitle( int options, const QString& pattern )
     connect(m_find, SIGNAL( findNext() ), this, SLOT( slotFindNext() ) );
 
     m_findItem = (BugLVI *)m_listBugs->firstChild();
-    if ( options & KFindDialog::FromCursor && m_listBugs->currentItem() )
+    if ( options & KFind::FromCursor && m_listBugs->currentItem() )
         m_findItem = (BugLVI *)m_listBugs->currentItem();
 
     slotFindNext();
@@ -286,7 +284,7 @@ void CWBugListContainer::slotFindNext()
         res = m_find->find();
 
         if ( res == KFind::NoMatch ) {
-            if ( m_find->options() & KFindDialog::FindBackwards )
+            if ( m_find->options() & KFind::FindBackwards )
                 m_findItem = (BugLVI *)m_findItem->itemAbove();
             else
                 m_findItem = (BugLVI *)m_findItem->itemBelow();
