@@ -31,7 +31,6 @@ class QPrinter;
 class QWidget;
 
 class KTemporaryFile;
-class KToggleAction;
 class KUrl;
 class KAboutData;
 class KAction;
@@ -45,7 +44,6 @@ class KompareModelList;
 class DiffSettings;
 class ViewSettings;
 class KompareSplitter;
-class KompareProcess;
 
 /**
  * This is a "Part".  It does all the real work in a KPart
@@ -60,6 +58,7 @@ class KomparePart : public KParts::ReadWritePart,
                     public KompareInterface
 {
 	Q_OBJECT
+	Q_INTERFACES(KompareInterface)
 public:
 	/**
 	* Default constructor
@@ -104,6 +103,12 @@ public:
 
 	/** Compare, with diff, source with destination */
 	virtual void compare( const KUrl& sourceFile, const KUrl& destinationFile );
+	
+	/** Compare a Source file to a custom Destination string */
+	virtual void compareFileString( const KUrl & sourceFile, const QString & destination);
+	
+	/** Compare a custom Source string to a Destination file */
+	virtual void compareStringFile( const QString & source, const KUrl & destinationFile);
 
 	/** Compare, with diff, source with destination */
 	virtual void compareFiles( const KUrl& sourceFile, const KUrl& destinationFile );
@@ -194,6 +199,7 @@ protected slots:
 	void updateActions();
 	void updateCaption();
 	void updateStatus();
+	void compareAndUpdateAll();
 
 	void slotPaintRequested( QPrinter* );
 
