@@ -1,39 +1,40 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2005-2007                                               *
+ *   copyright (C) 2005-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "import_utils.h"
-// qt/kde includes
-#include <qmap.h>
-#include <qregexp.h>
+
+// app includes
+#include "uml.h"
+#include "umldoc.h"
+#include "umllistview.h"
+#include "umllistviewitem.h"
+#include "umlobject.h"
+#include "package.h"
+#include "folder.h"
+#include "enum.h"
+#include "classifier.h"
+#include "operation.h"
+#include "attribute.h"
+#include "template.h"
+#include "association.h"
+#include "object_factory.h"
+
+// kde includes
 #include <kmessagebox.h>
 #include <kdebug.h>
 #include <klocale.h>
-// app includes
-#include "../uml.h"
-#include "../umldoc.h"
-#include "../umllistview.h"
-#include "../umllistviewitem.h"
-#include "../umlobject.h"
-#include "../package.h"
-#include "../folder.h"
-#include "../enum.h"
-#include "../classifier.h"
-#include "../operation.h"
-#include "../attribute.h"
-#include "../template.h"
-#include "../association.h"
-#include "../object_factory.h"
 
-#include <stdlib.h>
+// qt includes
+#include <QtCore/QMap>
+#include <QtCore/QRegExp>
 
 namespace Import_Utils {
 
@@ -66,38 +67,68 @@ bool bPutAtGlobalScope = false;
  */
 QStringList incPathList;
 
-void putAtGlobalScope(bool yesno) {
+/**
+ * Control whether an object which is newly created by createUMLObject()
+ * is put at the global scope.
+ *
+ * @param yesno  When set to false, the object is created at the scope
+ *               given by the parentPkg argument of createUMLObject().
+ */
+void putAtGlobalScope(bool yesno)
+{
     bPutAtGlobalScope = yesno;
 }
 
-void setRelatedClassifier(UMLClassifier *c) {
+/**
+ * Set a related classifier for creation of dependencies on template
+ * parameters in createUMLObject().
+ */
+void setRelatedClassifier(UMLClassifier *c)
+{
     gRelatedClassifier = c;
 }
 
-void assignUniqueIdOnCreation(bool yesno) {
+/**
+ * Control whether the creation methods solicit a new unique ID for the
+ * created object.
+ * By default, unique ID generation is turned on.
+ *
+ * @param yesno   False turns UID generation off, true turns it on.
+ */
+void assignUniqueIdOnCreation(bool yesno)
+{
     Object_Factory::assignUniqueIdOnCreation(yesno);
 }
 
-bool newUMLObjectWasCreated() {
+/**
+ * Returns whether the last createUMLObject() actually created
+ * a new object or just returned an existing one.
+ */
+bool newUMLObjectWasCreated()
+{
     return bNewUMLObjectWasCreated;
 }
 
-QString formatComment(const QString &comment) {
+/**
+ * Strip comment lines of leading whitespace and stars.
+ */
+QString formatComment(const QString &comment)
+{
     if (comment.isEmpty())
         return comment;
 
-    QStringList lines = QStringList::split("\n", comment);
+    QStringList lines = comment.split('\n');
     QString& first = lines.first();
     QRegExp wordex("\\w");
-    if (first.startsWith("/*")) {
-        int wordpos = wordex.search(first);
+    if (first.startsWith(QLatin1String("/*"))) {
+        int wordpos = wordex.indexIn(first);
         if (wordpos != -1)
             first = first.mid(wordpos);  // remove comment start
         else
             lines.pop_front();  // nothing interesting on this line
     }
     QString& last = lines.last();
-    int endpos = last.find("*/");
+    int endpos = last.indexOf("*/");
     if (endpos != -1) {
         if (last.contains(wordex))
             last = last.mid(0, endpos - 1);  // remove comment end
@@ -105,7 +136,7 @@ QString formatComment(const QString &comment) {
             lines.pop_back();  // nothing interesting on this line
     }
     if (! lines.count())
-        return "";
+        return QString();
 
     QStringList::Iterator end(lines.end());
     for (QStringList::Iterator lit(lines.begin()); lit != end; ++lit) {
@@ -116,25 +147,29 @@ QString formatComment(const QString &comment) {
 }
 
 /*
-UMLObject* findUMLObject(QString name,
-                                      Uml::Object_Type type) {
+UMLObject* findUMLObject(QString name, Uml::Object_Type type)
+{
     // Why an extra wrapper? See comment at addMethodParameter()
     UMLObject * o = umldoc->findUMLObject(name, type);
     return o;
 }
  */
 
+/**
+ * Find or create a document object.
+ */
 UMLObject *createUMLObject(Uml::Object_Type type,
                            const QString& inName,
                            UMLPackage *parentPkg,
                            const QString& comment,
-                           const QString& stereotype) {
+                           const QString& stereotype)
+{
     QString name = inName;
     UMLDoc *umldoc = UMLApp::app()->getDocument();
     UMLFolder *logicalView = umldoc->getRootFolder(Uml::mt_Logical);
     const Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
     if (parentPkg == NULL) {
-        // kDebug() << "Import_Utils::createUMLObject(" << name
+        // uDebug() << "Import_Utils::createUMLObject(" << name
         //     << "): parentPkg is NULL, assuming Logical View" << endl;
         parentPkg = logicalView;
     }
@@ -142,14 +177,14 @@ UMLObject *createUMLObject(Uml::Object_Type type,
     bNewUMLObjectWasCreated = false;
     if (o == NULL) {
         // Strip possible adornments and look again.
-        int isConst = name.contains(QRegExp("^const "));
+        const bool isConst = name.contains(QRegExp("^const "));
         name.remove(QRegExp("^const\\s+"));
         QString typeName(name);
-        const int isAdorned = typeName.contains( QRegExp("[^\\w:\\. ]") );
-        const int isPointer = typeName.contains('*');
-        const int isRef = typeName.contains('&');
+        const bool isAdorned = typeName.contains( QRegExp("[^\\w:\\. ]") );
+        const bool isPointer = typeName.contains('*');
+        const bool isRef = typeName.contains('&');
         typeName.remove(QRegExp("[^\\w:\\. ].*$"));
-        typeName = typeName.simplifyWhiteSpace();
+        typeName = typeName.simplified();
         UMLObject *origType = umldoc->findUMLObject(typeName, Uml::ot_UMLObject, parentPkg);
         if (origType == NULL) {
             // Still not found. Create the stripped down type.
@@ -158,9 +193,9 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             // Find, or create, the scopes.
             QStringList components;
             if (typeName.contains("::")) {
-                components = QStringList::split("::", typeName);
+                components = typeName.split("::");
             } else if (typeName.contains(".")) {
-                components = QStringList::split(".", typeName);
+                components = typeName.split('.');
             }
             if (components.count() > 1) {
                 typeName = components.back();
@@ -178,9 +213,9 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                         /* We know std and Qt are namespaces */
                         if (scopeName != "std" && scopeName != "Qt") {
                             wantNamespace = KMessageBox::questionYesNo(NULL,
-                                        i18n("Is the scope %1 a namespace or a class?").arg(scopeName),
+                                        i18n("Is the scope %1 a namespace or a class?", scopeName),
                                         i18n("C++ Import Requests Your Help"),
-                                        i18n("Namespace"), i18n("Class"));
+                                        KGuiItem(i18nc("namespace scope", "Namespace")), KGuiItem(i18nc("class scope", "Class")));
                         }
                     }
                     Uml::Object_Type ot = (wantNamespace == KMessageBox::Yes ? Uml::ot_Package : Uml::ot_Class);
@@ -212,9 +247,8 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             if (c)
                 dt->setOriginType(c);
             else
-                kError() << "createUMLObject(" << name << "): "
-                << "origType " << typeName << " is not a UMLClassifier"
-                << endl;
+                uError() << "createUMLObject(" << name << "): "
+                << "origType " << typeName << " is not a UMLClassifier";
             if (isRef || isPointer)
                 dt->setIsReference();
             /*
@@ -234,8 +268,8 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             if (existingPkg)
                 existingPkg->removeObject(o);
             else
-                kError() << "createUMLObject(" << name << "): "
-                    << "o->getUMLPackage() was NULL" << endl;
+                uError() << "createUMLObject(" << name << "): "
+                    << "o->getUMLPackage() was NULL";
             o->setUMLPackage(parentPkg);
             parentPkg->addObject(o);
         }
@@ -250,16 +284,16 @@ UMLObject *createUMLObject(Uml::Object_Type type,
     if (gRelatedClassifier == NULL || gRelatedClassifier == o)
         return o;
     QRegExp templateInstantiation("^[\\w:\\.]+\\s*<(.*)>");
-    int pos = templateInstantiation.search(name);
+    int pos = templateInstantiation.indexIn(name);
     if (pos == -1)
         return o;
     // Create dependencies on template parameters.
     QString caption = templateInstantiation.cap(1);
-    QStringList params = QStringList::split(QRegExp("[^\\w:\\.]+"), caption);
+    const QStringList params = caption.split(QRegExp("[^\\w:\\.]+"));
     if (!params.count())
         return o;
-    QStringList::Iterator end(params.end());
-    for (QStringList::Iterator it(params.begin()); it != end; ++it) {
+    QStringList::ConstIterator end(params.end());
+    for (QStringList::ConstIterator it(params.begin()); it != end; ++it) {
         UMLObject *p = umldoc->findUMLObject(*it, Uml::ot_UMLObject, parentPkg);
         if (p == NULL || p->getBaseType() == Uml::ot_Datatype)
             continue;
@@ -274,22 +308,37 @@ UMLObject *createUMLObject(Uml::Object_Type type,
     return o;
 }
 
-UMLOperation* makeOperation(UMLClassifier *parent, const QString &name) {
+/**
+ * Create a UMLOperation.
+ * The reason for this method is to not generate any Qt signals.
+ * Instead, these are generated by insertMethod().
+ * (If we generated a creation signal prematurely, i.e. without
+ * the method parameters being known yet, then that would lead to
+ * a conflict with a pre-existing parameterless method of the same
+ * name.)
+ */
+UMLOperation* makeOperation(UMLClassifier *parent, const QString &name)
+{
     UMLOperation *op = Object_Factory::createOperation(parent, name);
     return op;
 }
 
+/**
+ * Create a UMLAttribute and insert it into the document.
+ * Use the specified existing attrType.
+ */
 UMLObject* insertAttribute(UMLClassifier *owner,
                            Uml::Visibility scope,
                            const QString& name,
                            UMLClassifier *attrType,
                            const QString& comment /* ="" */,
-                           bool isStatic /* =false */) {
+                           bool isStatic /* =false */)
+{
     Uml::Object_Type ot = owner->getBaseType();
     Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
-    if (! (ot == Uml::ot_Class || ot == Uml::ot_Interface && pl == Uml::pl_Java)) {
-        kDebug() << "insertAttribute: Don't know what to do with "
-        << owner->getName() << " (object type " << ot << ")" << endl;
+    if (! (ot == Uml::ot_Class || (ot == Uml::ot_Interface && pl == Uml::pl_Java))) {
+        uDebug() << "insertAttribute: Don not know what to do with "
+                 << owner->getName() << " (object type " << ot << ")";
         return NULL;
     }
     UMLObject *o = owner->findChildObject(name, Uml::ot_Attribute);
@@ -308,11 +357,15 @@ UMLObject* insertAttribute(UMLClassifier *owner,
     return attr;
 }
 
+/**
+ * Create a UMLAttribute and insert it into the document.
+ */
 UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility scope,
                            const QString& name,
                            const QString& type,
                            const QString& comment /* ="" */,
-                           bool isStatic /* =false */) {
+                           bool isStatic /* =false */)
+{
     UMLObject *attrType = owner->findTemplate(type);
     if (attrType == NULL) {
         bPutAtGlobalScope = true;
@@ -326,11 +379,30 @@ UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility scope,
                             comment, isStatic);
 }
 
+/**
+  * Insert the UMLOperation into the given classifier.
+  *
+  * @param klass          The classifier into which the operation shall be added.
+  * @param op             Reference to pointer to the temporary UMLOperation
+  *                       for insertion.  The caller relinquishes ownership of the
+  *                       object pointed to.  If an UMLOperation of same signature
+  *                       already exists  at the classifier then the incoming
+  *                       UMLOperation is deleted and the pointer is set to the
+  *                       existing UMLOperation.
+  * @param scope          The Uml::Visibility of the method
+  * @param type           The return type
+  * @param isStatic       boolean switch to decide if method is static
+  * @param isAbstract     boolean switch to decide if method is abstract
+  * @param isFriend       true boolean switch to decide if methods is a friend function
+  * @param isConstructor  boolean switch to decide if methods is a constructor
+  * @param comment        The Documentation for this method
+  */
 void insertMethod(UMLClassifier *klass, UMLOperation* &op,
                   Uml::Visibility scope, const QString& type,
                   bool isStatic, bool isAbstract,
                   bool isFriend, bool isConstructor,
-                  const QString& comment) {
+                  const QString& comment)
+{
     op->setVisibility(scope);
     if (!type.isEmpty()     // return type may be missing (constructor/destructor)
         && type != "void") {
@@ -374,9 +446,8 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
         if (! strippedComment.isEmpty())
             exist->setDoc(strippedComment);
         UMLAttributeList exParams = exist->getParmList();
-        UMLAttribute *param, *exParam = exParams.first();
-        for (UMLAttributeListIt it(params); (param = it.current()) != NULL;
-                                            ++it, exParam = exParams.next()) {
+        for (UMLAttributeListIt it(params), exIt( exParams ) ; it.hasNext() ;) {
+            UMLAttribute *param = it.next() , *exParam = exIt.next();
             exParam->setName(param->getName());
             exParam->setVisibility(param->getVisibility());
             exParam->setStatic(param->getStatic());
@@ -393,9 +464,15 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
     }
 }
 
+/**
+ * Add an argument to a UMLOperation.
+ * The parentPkg arg is only used for resolving possible scope
+ * prefixes in the `type'.
+ */
 UMLAttribute* addMethodParameter(UMLOperation *method,
                                  const QString& type,
-                                 const QString& name) {
+                                 const QString& name)
+{
     UMLClassifier *owner = static_cast<UMLClassifier*>(method->parent());
     UMLObject *typeObj = owner->findTemplate(type);
     if (typeObj == NULL) {
@@ -410,12 +487,21 @@ UMLAttribute* addMethodParameter(UMLOperation *method,
     return attr;
 }
 
-void addEnumLiteral(UMLEnum *enumType, const QString &literal, const QString &comment) {
+/**
+ * Add an enum literal to an UMLEnum.
+ */
+void addEnumLiteral(UMLEnum *enumType, const QString &literal, const QString &comment)
+{
     UMLObject *el = enumType->addEnumLiteral(literal);
     el->setDoc(comment);
 }
 
-void createGeneralization(UMLClassifier *child, UMLClassifier *parent) {
+/**
+ * Create a generalization from the given child classifier to the given
+ * parent classifier.
+ */
+void createGeneralization(UMLClassifier *child, UMLClassifier *parent)
+{
     // if the child is an interface, so is the parent.
     if (child->isInterface())
         parent->setBaseType(Uml::ot_Interface);
@@ -433,32 +519,50 @@ void createGeneralization(UMLClassifier *child, UMLClassifier *parent) {
     umldoc->addAssociation(assoc);
 }
 
-void createGeneralization(UMLClassifier *child, const QString &parentName) {
+/**
+ * Create a generalization from the existing child UMLObject to the given
+ * parent class name.
+ */
+void createGeneralization(UMLClassifier *child, const QString &parentName)
+{
     UMLObject *parentObj = createUMLObject( Uml::ot_Class, parentName );
     UMLClassifier *parent = static_cast<UMLClassifier*>(parentObj);
     createGeneralization(child, parent);
 }
 
-QStringList includePathList() {
+/**
+ * Return the list of paths set by previous calls to addIncludePath()
+ * and the environment variable UMBRELLO_INCPATH.
+ * This list can be used for finding included (or Ada with'ed or...)
+ * files.
+ */
+QStringList includePathList()
+{
     QStringList includePathList(incPathList);
-    char *umbrello_incpath = getenv( "UMBRELLO_INCPATH" );
-    if (umbrello_incpath) {
-        includePathList += QStringList::split( ':', umbrello_incpath );
+    QString umbrello_incpath = QString(qgetenv("UMBRELLO_INCPATH"));
+    if (!umbrello_incpath.isEmpty()) {
+        includePathList += umbrello_incpath.split( ':' );
     }
     return includePathList;
 }
 
-void addIncludePath(const QString& path) {
+/**
+ * Add a path to the include path list.
+ */
+void addIncludePath(const QString& path)
+{
     if (! incPathList.contains(path))
         incPathList.append(path);
 }
 
-
-bool isDatatype(const QString& name, UMLPackage *parentPkg) {
+/**
+ * Returns true if a type is an actual Datatype
+ */
+bool isDatatype(const QString& name, UMLPackage *parentPkg)
+{
     UMLDoc *umldoc = UMLApp::app()->getDocument();
     UMLObject * o = umldoc->findUMLObject(name, Uml::ot_Datatype, parentPkg);
     return (o!=NULL);
 }
 
 }  // end namespace Import_Utils
-
