@@ -4,18 +4,13 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2008                                               *
+ *   copyright (C) 2002-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "operation.h"
 
-// qt/kde includes
-#include <QtCore/QRegExp>
-#include <kdebug.h>
-#include <klocale.h>
-
 // app includes
 #include "attribute.h"
 #include "classifier.h"
@@ -27,10 +22,28 @@
 #include "codedocument.h"
 #include "codeblock.h"
 
+// kde includes
+#include <kdebug.h>
+#include <klocale.h>
 
+// qt includes
+#include <QtCore/QRegExp>
+
+/**
+ * Constructs an UMLOperation.
+ * Not intended for general use: The operation is not tied in with
+ * umbrello's Qt signalling for object creation.
+ * If you want to create an Operation use the method in UMLDoc instead.
+ *
+ * @param parent    the parent to this operation
+ * @param name      the name of the operation
+ * @param id        the id of the operation
+ * @param s         the visibility of the operation
+ * @param rt        the return type of the operation
+ */
 UMLOperation::UMLOperation(UMLClassifier *parent, const QString& name,
                            Uml::IDType id, Uml::Visibility s, UMLObject *rt)
-        : UMLClassifierListItem(parent, name, id)
+  : UMLClassifierListItem(parent, name, id)
 {
     if (rt)
         m_returnId = UniqueID::gen();
@@ -40,28 +53,49 @@ UMLOperation::UMLOperation(UMLClassifier *parent, const QString& name,
     m_Vis = s;
     m_BaseType = Uml::ot_Operation;
     m_bConst = false;
-    m_Code = QString();
+    m_Code.clear();
 }
 
+/**
+ * Constructs an UMLOperation.
+ * Not intended for general use: The operation is not tied in with
+ * umbrello's Qt signalling for object creation.
+ * If you want to create an Operation use the method in UMLDoc instead.
+ *
+ * @param parent    the parent to this operation
+ */
 UMLOperation::UMLOperation(UMLClassifier * parent)
-        : UMLClassifierListItem (parent)
+  : UMLClassifierListItem (parent)
 {
     m_BaseType = Uml::ot_Operation;
     m_bConst = false;
-    m_Code = QString();
+    m_Code.clear();
 }
 
+/**
+ * Destructor.
+ */
 UMLOperation::~UMLOperation()
 {
 }
 
-void UMLOperation::setType(UMLObject *type)
+/**
+ * Reimplement method from UMLClassifierListItem.
+ *
+ * @param type      pointer to the type object
+ */
+void UMLOperation::setType(UMLObject* type)
 {
     UMLClassifierListItem::setType(type);
     if (m_returnId == Uml::id_None)
         m_returnId = UniqueID::gen();
 }
 
+/**
+ * Move a parameter one position to the left.
+ *
+ * @param a         the parameter to move
+ */
 void UMLOperation::moveParmLeft(UMLAttribute * a)
 {
     if (a == NULL) {
@@ -81,6 +115,11 @@ void UMLOperation::moveParmLeft(UMLAttribute * a)
     m_List.insert( idx-1, a );
 }
 
+/**
+ * Move a parameter one position to the right.
+ *
+ * @param a         the parameter to move
+ */
 void UMLOperation::moveParmRight(UMLAttribute * a)
 {
     if (a == NULL) {
@@ -101,6 +140,14 @@ void UMLOperation::moveParmRight(UMLAttribute * a)
     m_List.insert( idx+1, a );
 }
 
+/**
+ * Remove a parameter from the operation.
+ *
+ * @param a         the parameter to remove
+ * @param emitModifiedSignal  whether to emit the "modified" signal
+ *                  which creates an entry in the Undo stack for the
+ *                  removal, default: true
+ */
 void UMLOperation::removeParm(UMLAttribute * a, bool emitModifiedSignal /* =true */)
 {
     if (a == NULL) {
@@ -116,6 +163,22 @@ void UMLOperation::removeParm(UMLAttribute * a, bool emitModifiedSignal /* =true
         emit modified();
 }
 
+/**
+ * Returns a list of parameters.
+ *
+ * @return a list of the parameters in the operation
+ */
+UMLAttributeList UMLOperation::getParmList() const
+{
+    return m_List;
+}
+
+/**
+ * Finds a parameter of the operation.
+ *
+ * @param name      the parameter name to search for
+ * @return          the found parameter, 0 if not found
+ */
 UMLAttribute* UMLOperation::findParm(const QString &name)
 {
     UMLAttribute * obj=0;
@@ -126,11 +189,17 @@ UMLAttribute* UMLOperation::findParm(const QString &name)
     return 0;
 }
 
+/**
+ * Returns a string representation of the operation.
+ *
+ * @param sig       what type of operation string to show
+ * @return          the string representation of the operation
+ */
 QString UMLOperation::toString(Uml::Signature_Type sig)
 {
-    QString s = "";
+    QString s;
 
-    if(sig == Uml::st_ShowSig || sig == Uml::st_NoSig)
+    if (sig == Uml::st_ShowSig || sig == Uml::st_NoSig)
           s = m_Vis.toString(true) + ' ';
 
     s += getName();
@@ -169,7 +238,7 @@ QString UMLOperation::toString(Uml::Signature_Type sig)
     if (returnType.length() > 0 && returnType != "void") {
         s.append(" : ");
 
-        if (returnType.startsWith("virtual ")) {
+        if (returnType.startsWith(QLatin1String("virtual "))) {
             s += returnType.mid(8);
         } else {
             s += returnType;
@@ -178,6 +247,14 @@ QString UMLOperation::toString(Uml::Signature_Type sig)
     return s;
 }
 
+/**
+ * Add a parameter to the operation.
+ *
+ * @param parameter the parameter to add
+ * @param position  the position in the parameter list.
+ *                  If position = -1 the parameter will be
+ *                  appended to the list.
+ */
 void UMLOperation::addParm(UMLAttribute *parameter, int position)
 {
     if( position >= 0 && position <= (int)m_List.count() )
@@ -188,36 +265,46 @@ void UMLOperation::addParm(UMLAttribute *parameter, int position)
     connect(parameter,SIGNAL(modified()),this,SIGNAL(modified()));
 }
 
+/**
+ * Returns an unused parameter name for a new parameter.
+ */
 QString UMLOperation::getUniqueParameterName()
 {
     QString currentName = i18n("new_parameter");
     QString name = currentName;
-    for (int number = 1; findParm(name); number++) {
+    for (int number = 1; findParm(name); ++number) {
         name = currentName + '_' + QString::number(number);
     }
     return name;
 }
 
+/**
+ * Overloaded '==' operator.
+ */
 bool UMLOperation::operator==(const  UMLOperation & rhs )
 {
-    if( this == &rhs )
+    if ( this == &rhs )
         return true;
 
-    if( !UMLObject::operator==( rhs ) )
+    if ( !UMLObject::operator==( rhs ) )
         return false;
 
-    if( getTypeName() != rhs.getTypeName() )
+    if ( getTypeName() != rhs.getTypeName() )
         return false;
 
-    if( m_List.count() != rhs.m_List.count() )
+    if ( m_List.count() != rhs.m_List.count() )
         return false;
 
-    if(!(m_List == rhs.m_List))
+    if (!(m_List == rhs.m_List))
         return false;
 
     return true;
 }
 
+/**
+ * Copy the internal presentation of this object into the new
+ * object.
+ */
 void UMLOperation::copyInto(UMLObject *lhs) const
 {
     UMLOperation *target = static_cast<UMLOperation*>(lhs);
@@ -227,6 +314,9 @@ void UMLOperation::copyInto(UMLObject *lhs) const
     m_List.copyInto(&(target->m_List));
 }
 
+/**
+ * Make a clone of this object.
+ */
 UMLObject* UMLOperation::clone() const
 {
     //FIXME: The new operation should be slaved to the NEW parent not the old.
@@ -236,6 +326,12 @@ UMLObject* UMLOperation::clone() const
     return clone;
 }
 
+/**
+ * Calls resolveRef() on all parameters.
+ * Needs to be called after all UML objects are loaded from file.
+ *
+ * @return  true for success
+ */
 bool UMLOperation::resolveRef()
 {
     bool overallSuccess = UMLObject::resolveRef();
@@ -247,6 +343,11 @@ bool UMLOperation::resolveRef()
     return overallSuccess;
 }
 
+/**
+ * Returns whether this operation is a constructor.
+ *
+ * @return  true if this operation is a constructor
+ */
 bool UMLOperation::isConstructorOperation()
 {
     // if an operation has the stereotype constructor
@@ -263,6 +364,11 @@ bool UMLOperation::isConstructorOperation()
     return (cName == opName);
 }
 
+/**
+ * Returns whether this operation is a destructor.
+ *
+ * @return  true if this operation is a destructor
+ */
 bool UMLOperation::isDestructorOperation()
 {
     if (getStereotype() == "destructor")
@@ -280,37 +386,64 @@ bool UMLOperation::isDestructorOperation()
     return (cName == opName);
 }
 
+/**
+ * Shortcut for (isConstructorOperation() || isDestructorOperation()).
+ *
+ * @return  true if this operation is a constructor or destructor
+ */
 bool UMLOperation::isLifeOperation()
 {
     return (isConstructorOperation() || isDestructorOperation());
 }
 
+/**
+ * Sets whether this operation is a query (C++ "const").
+ */
 void UMLOperation::setConst(bool b)
 {
     m_bConst = b;
 }
 
+/**
+ * Returns whether this operation is a query (C++ "const").
+ */
 bool UMLOperation::getConst() const
 {
     return m_bConst;
 }
 
+/**
+ * Display the properties configuration dialog for the template.
+ *
+ * @param parent   the parent for the dialog
+ */
 bool UMLOperation::showPropertiesDialog(QWidget* parent)
 {
     UMLOperationDialog dialog(parent, this);
     return dialog.exec();
 }
 
+/**
+ * Sets the source code for this operation.
+ *
+ * @param code  the body of this operation
+ */
 void UMLOperation::setSourceCode(const QString& code)
 {
     m_Code = code;
 }
 
+/**
+ * Returns the source code for this operation.
+ */
 QString UMLOperation::getSourceCode() const
 {
     return m_Code;
 }
 
+/**
+ * Saves to the <UML:Operation> XMI element.
+ */
 void UMLOperation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
 {
     QDomElement operationElement = UMLObject::save("UML:Operation", qDoc);
@@ -337,9 +470,9 @@ void UMLOperation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
         if (attrType) {
             attElement.setAttribute( "type", ID2STR(attrType->getID()) );
         } else {
-            attElement.setAttribute( "type", pAtt -> getTypeName() );
+            attElement.setAttribute( "type", pAtt->getTypeName() );
         }
-        attElement.setAttribute( "value", pAtt -> getInitialValue() );
+        attElement.setAttribute( "value", pAtt->getInitialValue() );
 
         Uml::Parameter_Direction kind = pAtt->getParmKind();
         if (kind == Uml::pd_Out)
@@ -356,6 +489,9 @@ void UMLOperation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
     qElement.appendChild( operationElement );
 }
 
+/**
+ * Loads a <UML:Operation> XMI element.
+ */
 bool UMLOperation::load( QDomElement & element )
 {
     m_SecondaryId = element.attribute( "type", "" );
