@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2006                                               *
+ *   copyright (C) 2003-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -13,7 +13,6 @@
 #include "template.h"
 
 // qt/kde includes
-#include <qregexp.h>
 #include <kdebug.h>
 
 // app includes
@@ -21,14 +20,14 @@
 #include "umldoc.h"
 #include "dialogs/umltemplatedialog.h"
 
-UMLTemplate::UMLTemplate(const UMLObject *parent, const QString& name,
+UMLTemplate::UMLTemplate(UMLObject *parent, const QString& name,
                          Uml::IDType id, const QString& type)
         : UMLClassifierListItem( parent, name, id ) {
     setTypeName( type );
     m_BaseType = Uml::ot_Template;
 }
 
-UMLTemplate::UMLTemplate(const UMLObject *parent)
+UMLTemplate::UMLTemplate(UMLObject *parent)
         : UMLClassifierListItem( parent ) {
     m_BaseType = Uml::ot_Template;
 }
@@ -43,13 +42,22 @@ QString UMLTemplate::toString(Uml::Signature_Type /*sig = st_NoSig*/) {
     }
 }
 
-QString UMLTemplate::getTypeName() {
+/**
+ * Overrides method from UMLClassifierListItem.
+ * Returns the type name of the UMLTemplate.
+ * If the template parameter is a class, there is no separate
+ * type object. In this case, getTypeName() returns "class".
+ *
+ * @return  The type name of the UMLClassifierListItem.
+ */
+QString UMLTemplate::getTypeName() const
+{
     if (m_pSecondary == NULL)
         return "class";
     return m_pSecondary->getName();
 }
 
-bool UMLTemplate::operator==(UMLTemplate &rhs) {
+bool UMLTemplate::operator==(const UMLTemplate &rhs) {
     if (this == &rhs) {
         return true;
     }
@@ -62,11 +70,18 @@ bool UMLTemplate::operator==(UMLTemplate &rhs) {
     return true;
 }
 
-void UMLTemplate::copyInto(UMLTemplate *rhs) const
+/**
+ * Copy the internal presentation of this object into the new
+ * object.
+ */
+void UMLTemplate::copyInto(UMLObject *lhs) const
 {
-    UMLClassifierListItem::copyInto(rhs);
+    UMLClassifierListItem::copyInto(lhs);
 }
 
+/**
+ * Make a clone of this object.
+ */
 UMLObject* UMLTemplate::clone() const
 {
     UMLTemplate *clone = new UMLTemplate( (UMLTemplate*) parent());
@@ -76,6 +91,9 @@ UMLObject* UMLTemplate::clone() const
 }
 
 
+/**
+ * Writes the <UML:TemplateParameter> XMI element.
+ */
 void UMLTemplate::saveToXMI(QDomDocument& qDoc, QDomElement& qElement) {
     //FIXME: uml13.dtd compliance
     QDomElement attributeElement = UMLObject::save("UML:TemplateParameter", qDoc);
@@ -84,11 +102,19 @@ void UMLTemplate::saveToXMI(QDomDocument& qDoc, QDomElement& qElement) {
     qElement.appendChild(attributeElement);
 }
 
+/**
+ * Loads the <UML:TemplateParameter> XMI element.
+ */
 bool UMLTemplate::load(QDomElement& element) {
     m_SecondaryId = element.attribute("type", "");
     return true;
 }
 
+/**
+ * Display the properties configuration dialog for the template.
+ *
+ * @return  Success status.
+ */
 bool UMLTemplate::showPropertiesDialog(QWidget* parent) {
     UMLTemplateDialog dialog(parent, this);
     return dialog.exec();
