@@ -14,10 +14,10 @@
 
 #include <string>
 #include <QtCore/QString>
-
+#include <kdebug.h>
 
 /**
- *@author Paul Hensgen
+ * @author Paul Hensgen
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
 namespace Uml {
@@ -324,6 +324,8 @@ const IDType id_Reserved = "0";
 #define uError()   kError(8060)
 #define uWarning() kWarning(8060)
 
+#define uIgnoreZeroPointer(a) if (!a) { uDebug() << "zero pointer detected" << __FILE__ << __LINE__; continue; }
+
 /**
  * Function for comparing tags in XMI files.
  */
